# Welcome to cacholote's documentation!

Efficiently cache calls to functions.

```{toctree}
:caption: 'Contents:'
:maxdepth: 2

API Reference <_api/cacholote/index>
```

# Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
